"""
// © University of Southampton IT Innovation Centre, 2018
//
// Copyright in this software belongs to University of Southampton
// IT Innovation Centre of Gamma House, Enterprise Road, 
// Chilworth Science Park, Southampton, SO16 7NS, UK.
//
// This software may not be used, sold, licensed, transferred, copied
// or reproduced in whole or in part in any manner or form or in or
// on any media by any person other than in accordance with the terms
// of the Licence Agreement supplied with the software, or otherwise
// without the prior written consent of the copyright owners.
//
// This software is distributed WITHOUT ANY WARRANTY, without even the
// implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
// PURPOSE, except where stated in the Licence Agreement supplied with
// the software.
//
//      Created By :            Michael Boniface
//      Created Date :          25-03-2018
//      Created for Project :   FLAME
"""


import os
import os.path
from setuptools import setup, find_packages


def get_version(*relative_path):
    """
    Reads and parses a version file.

    :param relative_path: iterable representing the relative path to the version file
    :return:
    """

    fname = os.path.join(os.path.dirname(__file__), *relative_path)

    if os.path.isfile(fname):
        with open(fname) as f:  # Use context managers when opening files, otherwise file handlers might not be properly closed
            version = {}
            # execute the version file and put its content in the version dictionary
            exec(f.read(), version)
            # extract the __version__ variable from the dictionary, if not found use default value "SNAPSHOT"
            git_revision = version.get("__version__", "SNAPSHOT")
    else:
        git_revision = "SNAPSHOT"

    return git_revision


setup(
    name="clmctest",
    version=get_version("VERSION"),
    author="Michael Boniface",
    author_email="mjb@it-innovation.soton.ac.uk",
    description="FLAME CLMC Test Module",
    license="https://gitlab.it-innovation.soton.ac.uk/FLAME/flame-clmc/blob/integration/LICENSE",
    keywords="FLAME CLMC",
    url='https://gitlab.it-innovation.soton.ac.uk/FLAME/flame-clmc',
    packages=find_packages(),
    include_package_data=True,
    long_description="FLAME CLMC Test",
    classifiers=[
        "Development Status :: Alpha",
        "Topic :: FLAME Tests",
        "License :: ",
    ],
)
